@@ -1,4 +1,4 @@
-# !/usr/bin/env python3
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 from asyncio import AbstractEventLoop, run_coroutine_threadsafe
 from typing import BinaryIO, Dict, List, Optional, Tuple, Union
@@ -30,6 +30,10 @@ class API:
         )
         return future_.result()
 
+    @staticmethod
+    def get_bot_id():
+        raise DeprecationWarning("SDK版本>=2.3.2后已遗弃get_bot_id()的api，改为BOT.robot.id")
+
     def get_bot_info(self) -> _api_model.get_bot_info():
         """
         获取机器人详情
