@@ -1,4 +1,4 @@
-# !/usr/bin/env python3
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 from io import BufferedReader
 from json import loads
@@ -86,6 +86,10 @@ class AsyncAPI:
             return True
         return False
 
+    @staticmethod
+    async def get_bot_id():
+        raise DeprecationWarning("SDK版本>=2.3.2后已遗弃get_bot_id()的api，改为BOT.robot.id")
+
     async def get_bot_info(self) -> _api_model.get_bot_info():
         """
         获取机器人详情
@@ -706,13 +710,15 @@ class AsyncAPI:
         :param channel_id: 子频道id
         :param content: 消息文本（选填，此项与image至少需要有一个字段，否则无法下发消息）
         :param image: 图片url，不可发送本地图片（选填，此项与msg至少需要有一个字段，否则无法下发消息）
-        :param file_image: 本地图片，可选三种方式传参，具体可参阅github中的example_10或帮助文档
+        :param file_image: 本地图片，可选三种方式传参，具体可参阅github中的example_10或帮助文档，与image同时存在时优先使用此项
         :param message_id: 消息id（选填）
         :param event_id: 事件id（选填）
         :param message_reference_id: 引用消息的id（选填）
         :param ignore_message_reference_error: 是否忽略获取引用消息详情错误，默认否（选填）
         :return: 返回的.data中为解析后的json数据
         """
+        if content is not None and not isinstance(content, str):
+            content = str(content)
         if message_reference_id is not None:
             if ignore_message_reference_error is None:
                 ignore_message_reference_error = False
@@ -744,10 +750,12 @@ class AsyncAPI:
                     if file_image.startswith("http"):
                         return sdk_error_temp("发送网络图片请使用image参数，而非file_image")
                     return sdk_error_temp("目标图片路径不存在，无法发送")
+            elif not isinstance(file_image, bytes):
+                return sdk_error_temp(f"file_image不支持{type(file_image)}的内容")
             json_["file_image"] = file_image
             data_ = FormData_()
             for keys, values in json_.items():
-                if values is not None:
+                if values is not None and keys != "image":
                     data_.add_field(keys, values)
             return_ = await self._session.post(
                 f"{self.bot_url}/channels/{channel_id}/messages", data=data_
@@ -792,7 +800,7 @@ class AsyncAPI:
         }
         if content is not None:
             for items in content:
-                json_["embed"]["fields"].append({"name": items})
+                json_["embed"]["fields"].append({"name": str(items)})
         return_ = await self._session.post(
             f"{self.bot_url}/channels/{channel_id}/messages", json=json_
         )
@@ -834,12 +842,16 @@ class AsyncAPI:
             "msg_id": message_id,
             "event_id": event_id,
         }
-        for i, items in enumerate(content):
+        for _link, _content in zip(link, content):
+            if _content is not None and not isinstance(_content, str):
+                _content = str(_content)
+            if _link is not None and not isinstance(_link, str):
+                _link = str(_link)
             json_["ark"]["kv"][2]["obj"].append(
                 {
                     "obj_kv": [
-                        {"key": "desc", "value": items},
-                        {"key": "link", "value": link[i]},
+                        {"key": "desc", "value": _content},
+                        {"key": "link", "value": _link},
                     ]
                 }
             )
@@ -1083,7 +1095,7 @@ class AsyncAPI:
         :param guild_id: 虚拟频道id（非子频道id），从用户主动私信机器人的事件、或机器人主动创建私信的API中获取
         :param content: 消息内容文本
         :param image: 图片url，不可发送本地图片（选填，此项与msg至少需要有一个字段，否则无法下发消息）
-        :param file_image: 本地图片，可选三种方式传参，具体可参阅github中的example_10或帮助文档
+        :param file_image: 本地图片，可选三种方式传参，具体可参阅github中的example_10或帮助文档，与image同时存在时优先使用此项
         :param message_id: 消息id（选填）
         :param event_id: 事件id（选填）
         :param message_reference_id: 引用消息的id（选填）
@@ -1121,10 +1133,12 @@ class AsyncAPI:
                     if file_image.startswith("http"):
                         return sdk_error_temp("发送网络图片请使用image参数，而非file_image")
                     return sdk_error_temp("目标图片路径不存在，无法发送")
+            elif not isinstance(file_image, bytes):
+                return sdk_error_temp(f"file_image不支持{type(file_image)}的内容")
             json_["file_image"] = file_image
             data_ = FormData_()
             for keys, values in json_.items():
-                if values is not None:
+                if values is not None and keys != "image":
                     data_.add_field(keys, values)
             return_ = await self._session.post(
                 f"{self.bot_url}/dms/{guild_id}/messages", data=data_
