@@ -1,4 +1,4 @@
-# !/usr/bin/env python3
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 from asyncio import Lock as ALock
 from asyncio import get_event_loop, new_event_loop, sleep
@@ -43,6 +43,7 @@ class BOT:
         total_shard: int = 1,
         max_workers: int = 32,
         api_max_concurrency: int = 0,
+        api_timeout: int = 20,
     ):
         """
         机器人主体，输入BotAppID和密钥，并绑定函数后即可快速使用
@@ -59,7 +60,8 @@ class BOT:
         :param shard_no: 当前分片数，如不熟悉相关配置请不要轻易改动此项，默认0
         :param total_shard: 最大分片数，如不熟悉相关配置请不要轻易改动此项，默认1
         :param max_workers: 在同步模式下，允许同时运行的最大线程数，默认32
-        :param api_max_concurrency: API允许的最大并发数，超过此并发数将进入队列，如此数值<=0代表不开启任何队列
+        :param api_max_concurrency: API允许的最大并发数，超过此并发数将进入队列，如此数值<=0代表不开启任何队列，默认0
+        :param api_timeout: API请求的超时设置。默认20
         """
         self.logger = Logger(bot_id)
         self.bot_id = bot_id
@@ -69,11 +71,13 @@ class BOT:
                 "bot_secret已被废弃，如需使用安全接口，请通过security_setup()绑定小程序ID和secret"
             )
         self.is_private = is_private
-        self.bot_url = (
-            r"https://sandbox.api.sgroup.qq.com"
-            if is_sandbox
-            else r"https://api.sgroup.qq.com"
-        )
+        if is_sandbox:
+            self.logger.info(
+                "已开启沙箱环境，发送消息时将频道方将自动添加[sandbox]字样，如需关闭请传参is_sandbox=False"
+            )
+            self.bot_url = r"https://sandbox.api.sgroup.qq.com"
+        else:
+            self.bot_url = r"https://api.sgroup.qq.com"
         if not bot_id or not bot_token:
             raise type("IdTokenMissing", (Exception,), {})(
                 "你还没有输入 bot_id 和 bot_token，无法连接使用机器人\n如尚未有相关票据，"
@@ -114,6 +118,7 @@ class BOT:
             is_log_error,
             self.logger,
             api_max_concurrency,
+            api_timeout,
             headers=self.bot_headers,
         )
         self.msg_treat = True
