@@ -1,4 +1,4 @@
-# !/usr/bin/env python3
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 from asyncio import all_tasks, get_event_loop, new_event_loop, sleep
 from concurrent.futures import ThreadPoolExecutor
@@ -6,6 +6,7 @@ from copy import copy, deepcopy
 from json import dumps, loads
 from ssl import create_default_context
 from typing import Any, Callable, Union
+from unittest.mock import PropertyMock, patch
 
 from aiohttp import ClientSession, WSMsgType, WSServerHandshakeError
 
@@ -23,6 +24,7 @@ from .async_api import AsyncAPI
 from .http import Session
 from .logger import Logger
 from .model import Model
+from .plugins import Plugins
 
 
 class BotWs:
@@ -194,11 +196,15 @@ class BotWs:
 
     @exception_processor
     async def async_start_task(self, func, *args):
-        await func(*args)
+        with patch.object(Plugins, "api", new_callable=PropertyMock) as mock_api:
+            mock_api.return_value = self.api
+            await func(*args)
 
     @exception_processor
     def start_task(self, func, *args):
-        func(*args)
+        with patch.object(Plugins, "api", new_callable=PropertyMock) as mock_api:
+            mock_api.return_value = self.api
+            func(*args)
 
     @exception_processor
     async def distribute(
@@ -238,34 +244,46 @@ class BotWs:
 
     @exception_processor
     async def check_command(
-        self, objectized_data: Model.MESSAGE, treated_msg, items, **kwargs
+        self, objectized_data: Model.MESSAGE, treated_msg, command_obj, **kwargs
     ):
-        if items["admin"]:
-            roles = objectized_data.member.roles
+        # command: {command or regex, func, treat, at, short_circuit, admin, admin_error_msg}
+        if command_obj["admin"]:
+            try:
+                roles = objectized_data.member.roles
+            except Exception:
+                command_str = kwargs.get("command") or getattr(
+                    kwargs.get("regex"), "pattern", None
+                )
+                self.logger.error(
+                    f"cannot check roles of member for admin command: {command_str}"
+                )
+                return False
             if "2" not in roles and "4" not in roles:  # if not admin
-                if items["admin_error_msg"]:
+                if command_obj["admin_error_msg"]:
                     if self.is_async:
                         self.loop.create_task(
                             objectized_data.reply(
-                                items["admin_error_msg"],
+                                command_obj["admin_error_msg"],
                             )
                         )
                     else:
                         self.threads.submit(
                             objectized_data.reply,
-                            items["admin_error_msg"],
+                            command_obj["admin_error_msg"],
                         )
                     return True
                 return False
-        if items["treat"] and self.msg_treat:
+        if command_obj["treat"] and self.msg_treat:
             objectized_data = self.treat_command(objectized_data, treated_msg, **kwargs)
-        task = await self.distribute(items["func"], objectized_data=objectized_data)
-        if not items["is_custom_short_circuit"]:
-            return items["short_circuit"]  # True or False
-        else:
-            while not task.done():
-                await sleep(0.5)
-            return task.result()  # True or False
+            task = await self.distribute(
+                command_obj["func"], objectized_data=objectized_data
+            )
+            if not command_obj["is_custom_short_circuit"]:
+                return command_obj["short_circuit"]  # True or False
+            else:
+                while not task.done():
+                    await sleep(0.5)
+                return task.result()  # True or False
 
     @exception_processor
     async def distribute_commands(self, data, treated_msg):
